Module: ActionController::PolymorphicRoutes
- Included in:
- Routing::Helpers, ActionView::TestCase
- Defined in:
- lib/action_controller/polymorphic_routes.rb
Overview
Polymorphic URL helpers are methods for smart resolution to a named route call when given an Active Record model instance. They are to be used in combination with ActionController::Resources.
These methods are useful when you want to generate correct URL or path to a RESTful resource without having to know the exact type of the record in question.
Nested resources and/or namespaces are also supported, as illustrated in the example:
polymorphic_url([:admin, @article, @comment])
results in:
admin_article_comment_url(@article, @comment)
Usage within the framework
Polymorphic URL helpers are used in a number of places throughout the Rails framework:
- url_for, so you can use it with a record as the argument, e.g. url_for(@article);
- ActionView::Helpers::FormHelper uses polymorphic_path, so you can write form_for(@article) without having to specify :url parameter for the form action;
- redirect_to (which, in fact, uses url_for) so you can write redirect_to(post) in your controllers;
- ActionView::Helpers::AtomFeedHelper, so you don't have to explicitly specify URLs for feed entries.
Prefixed polymorphic helpers
In addition to polymorphic_url and polymorphic_path methods, a number of prefixed helpers are available as a shorthand to :action => "..." in options. Those are:
- edit_polymorphic_url, edit_polymorphic_path
- new_polymorphic_url, new_polymorphic_path
Example usage:
edit_polymorphic_path(@post) # => "/posts/1/edit"
polymorphic_path(@post, :format => :pdf) # => "/posts/1.pdf"
Instance Method Summary collapse
- #formatted_polymorphic_path(record_or_hash, options = {}) ⇒ Object
- #formatted_polymorphic_url(record_or_hash, options = {}) ⇒ Object
-
#polymorphic_path(record_or_hash_or_array, options = {}) ⇒ Object
Returns the path component of a URL for the given record.
-
#polymorphic_url(record_or_hash_or_array, options = {}) ⇒ Object
Constructs a call to a named RESTful route for the given record and returns the resulting URL string.
Instance Method Details
#formatted_polymorphic_path(record_or_hash, options = {}) ⇒ Object
139 140 141 142 143 |
# File 'lib/action_controller/polymorphic_routes.rb', line 139 def formatted_polymorphic_path(record_or_hash, = {}) ActiveSupport::Deprecation.warn("formatted_polymorphic_path has been deprecated. Please pass :format to the polymorphic_path method instead", caller) [:format] = record_or_hash.pop if record_or_hash === Array polymorphic_url(record_or_hash, .merge(:routing_type => :path)) end |
#formatted_polymorphic_url(record_or_hash, options = {}) ⇒ Object
133 134 135 136 137 |
# File 'lib/action_controller/polymorphic_routes.rb', line 133 def formatted_polymorphic_url(record_or_hash, = {}) ActiveSupport::Deprecation.warn("formatted_polymorphic_url has been deprecated. Please pass :format to the polymorphic_url method instead", caller) [:format] = record_or_hash.pop if Array === record_or_hash polymorphic_url(record_or_hash, ) end |
#polymorphic_path(record_or_hash_or_array, options = {}) ⇒ Object
Returns the path component of a URL for the given record. It uses polymorphic_url with :routing_type => :path.
112 113 114 115 |
# File 'lib/action_controller/polymorphic_routes.rb', line 112 def polymorphic_path(record_or_hash_or_array, = {}) [:routing_type] = :path polymorphic_url(record_or_hash_or_array, ) end |
#polymorphic_url(record_or_hash_or_array, options = {}) ⇒ Object
Constructs a call to a named RESTful route for the given record and returns the resulting URL string. For example:
# calls post_url(post)
polymorphic_url(post) # => "http://example.com/posts/1"
polymorphic_url([blog, post]) # => "http://example.com/blogs/1/posts/1"
polymorphic_url([:admin, blog, post]) # => "http://example.com/admin/blogs/1/posts/1"
polymorphic_url([user, :blog, post]) # => "http://example.com/users/1/blog/posts/1"
Options
- :action - Specifies the action prefix for the named route: :new or :edit. Default is no prefix.
- :routing_type - Allowed values are :path or :url. Default is :url.
Examples
# an Article record
polymorphic_url(record) # same as article_url(record)
# a Comment record
polymorphic_url(record) # same as comment_url(record)
# it recognizes new records and maps to the collection
record = Comment.new
polymorphic_url(record) # same as comments_url()
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/action_controller/polymorphic_routes.rb', line 73 def polymorphic_url(record_or_hash_or_array, = {}) if record_or_hash_or_array.kind_of?(Array) record_or_hash_or_array = record_or_hash_or_array.compact record_or_hash_or_array = record_or_hash_or_array[0] if record_or_hash_or_array.size == 1 end record = extract_record(record_or_hash_or_array) args = case record_or_hash_or_array when Hash; [ record_or_hash_or_array ] when Array; record_or_hash_or_array.dup else [ record_or_hash_or_array ] end inflection = case when [:action].to_s == "new" args.pop :singular when record.respond_to?(:new_record?) && record.new_record? args.pop :plural else :singular end args.delete_if {|arg| arg.is_a?(Symbol) || arg.is_a?(String)} named_route = build_named_route_call(record_or_hash_or_array, inflection, ) = .except(:action, :routing_type) unless .empty? args.last.kind_of?(Hash) ? args.last.merge!() : args << end __send__(named_route, *args) end |